==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/creative_tab/content/FoodCreativeTab.java <==
package cc.thonly.reverie_dreams.creative_tab.content;

import cc.thonly.mystias_izakaya.MystiasIzakaya;
import cc.thonly.mystias_izakaya.item.MIItems;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2561;
import net.minecraft.class_5321;
import net.minecraft.class_7924;

public class FoodCreativeTab implements ItemGroupContentHelper {

    public static final class_5321<class_1761> ITEM_GROUP_KEY = class_5321.method_29179(class_7924.field_44688, MystiasIzakaya.id("food_item_group"));
    public static final class_1761 ITEM_GROUP = ItemGroupContentHelper.builder()
            .method_47320(FoodCreativeTab::getFoodItemIcon)
            .method_47321(class_2561.method_43471("item_group.food_item_group"))
            .method_47324();

    public static void bootstrap() {
        ItemGroupEvents.modifyEntriesEvent(FoodCreativeTab.ITEM_GROUP_KEY).register(itemGroup -> {
            for (class_1792 item : MIItems.FOOD_ITEMS) {
                itemGroup.method_45421(item);
            }
        });
        ItemGroupContentHelper.registerGroup(FoodCreativeTab.ITEM_GROUP_KEY, FoodCreativeTab.ITEM_GROUP);

    }

    public static class_1799 getFoodItemIcon() {
        for (class_1792 foodItem : MIItems.FOOD_ITEMS) {
            return new class_1799(foodItem);
        }
        return new class_1799(class_1802.field_8176);
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/creative_tab/content/FoodCreativeTab.java <==
package cc.thonly.reverie_dreams.creative_tab.content;

import cc.thonly.reverie_dreams.ReverieDreams;
import cc.thonly.reverie_dreams.registry.content.item.RDFoodItems;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2561;
import net.minecraft.class_5321;
import net.minecraft.class_7924;

public class FoodCreativeTab implements ItemGroupContentHelper {

    public static final class_5321<class_1761> ITEM_GROUP_KEY = class_5321.method_29179(class_7924.field_44688, ReverieDreams.id("food_item_group"));
    public static final class_1761 ITEM_GROUP = ItemGroupContentHelper.builder()
            .method_47320(FoodCreativeTab::getFoodItemIcon)
            .method_47321(class_2561.method_43471("item_group.food_item_group"))
            .method_47324();

    public static void bootstrap() {
        ItemGroupEvents.modifyEntriesEvent(FoodCreativeTab.ITEM_GROUP_KEY).register(itemGroup -> {
            for (class_1792 item : RDFoodItems.FOOD_ITEMS) {
                itemGroup.method_45421(item);
            }
        });
        ItemGroupContentHelper.registerGroup(FoodCreativeTab.ITEM_GROUP_KEY, FoodCreativeTab.ITEM_GROUP);

    }

    public static class_1799 getFoodItemIcon() {
        for (class_1792 foodItem : RDFoodItems.FOOD_ITEMS) {
            return new class_1799(foodItem);
        }
        return new class_1799(class_1802.field_8176);
    }
}
